@@ -2,15 +2,27 @@
 # mocked and are skipped
 # https://github.com/ropensci/vcr/issues/270
 
-skip_long_tests <- as.logical(Sys.getenv("RNPN_SKIP_LONG_TESTS", unset = "true"))
+skip_long_tests <- as.logical(Sys.getenv(
+  "RNPN_SKIP_LONG_TESTS",
+  unset = "true"
+))
 
 test_that("no request source blocked", {
   skip_on_cran()
 
   expect_error(npn_download_status_data(request_source = NULL, years = 2013))
-  expect_error(npn_download_individual_phenometrics(request_source = NULL, years = 2013))
-  expect_error(npn_download_site_phenometrics(request_source = NULL, years = 2013))
-  expect_error(npn_download_magnitude_phenometrics(request_source = NULL, years = 2013))
+  expect_error(npn_download_individual_phenometrics(
+    request_source = NULL,
+    years = 2013
+  ))
+  expect_error(npn_download_site_phenometrics(
+    request_source = NULL,
+    years = 2013
+  ))
+  expect_error(npn_download_magnitude_phenometrics(
+    request_source = NULL,
+    years = 2013
+  ))
 })
 
 test_that("npn_download_status_data() works", {
@@ -29,7 +41,7 @@ test_that("npn_download_status_data() works", {
   skip_if_not(check_service(), "Service is down")
 
   ## Would be ideal to capture this with vcr, but doesn't work with httr2 downloads yet: https://github.com/ropensci/vcr/issues/270
-  some_data_file  <- npn_download_status_data(
+  some_data_file <- npn_download_status_data(
     request_source = "Unit Test",
     years = 2013,
     species_ids = c(6),
@@ -41,8 +53,10 @@ test_that("npn_download_status_data() works", {
   expect_equal(
     read.csv(some_data_file) %>%
       tibble::as_tibble() %>%
-      dplyr::mutate(update_datetime = as.POSIXct(update_datetime, tz = "UTC"),
-                    abundance_value = as.character(abundance_value)),
+      dplyr::mutate(
+        update_datetime = as.POSIXct(update_datetime, tz = "UTC"),
+        abundance_value = as.character(abundance_value)
+      ),
     some_data
   )
 })
@@ -122,6 +136,18 @@ test_that("phenometrics downloads work", {
 
   expect_gt(num_mag_custom, num_mag_default)
 
+  vcr::use_cassette("npn_download_no_records", {
+    expect_message(
+      dl <- npn_download_individual_phenometrics(
+        request_source = 'erinz',
+        years = 2009,
+        species_ids = 1612
+      ),
+      "No records in 2009"
+    )
+  })
+
+  expect_equal(dl, dplyr::tibble())
 })
 
 test_that("custom period works", {
@@ -168,12 +194,15 @@ test_that("custom period works", {
 
   #just crude checks that they aren't identical
   expect_false(
-    all(indiv_standard$last_yes_month[1:20] ==
-          indiv_wateryr$last_yes_month[1:20])
+    all(
+      indiv_standard$last_yes_month[1:20] == indiv_wateryr$last_yes_month[1:20]
+    )
   )
   expect_false(
-    all(site_standard$mean_last_yes_doy[1:20] ==
-          site_wateryr$mean_last_yes_doy[1:20])
+    all(
+      site_standard$mean_last_yes_doy[1:20] ==
+        site_wateryr$mean_last_yes_doy[1:20]
+    )
   )
 })
 
@@ -187,12 +216,12 @@ test_that("file download works", {
   test_download_path <- withr::local_tempfile(fileext = ".csv")
 
   # vcr::use_cassette("downloads", {
-    status_dl_file <- npn_download_status_data(
-      request_source = "Unit Test",
-      years = 2013,
-      species_ids = c(6),
-      download_path = test_download_path
-    )
+  status_dl_file <- npn_download_status_data(
+    request_source = "Unit Test",
+    years = 2013,
+    species_ids = c(6),
+    download_path = test_download_path
+  )
   # })
 
   expect_true(file.exists(status_dl_file))
@@ -203,7 +232,6 @@ test_that("file download works", {
   expect_type(some_data$species_id, "integer")
   expect_equal(some_data[1, ]$species_id, 6)
 
-
   some_data <- npn_download_magnitude_phenometrics(
     request_source = "Unit Test",
     years = 2013,
@@ -217,12 +245,10 @@ test_that("file download works", {
   expect_gt(nrow(some_data), 10)
   expect_type(some_data$species_id, "integer")
   expect_equal(some_data[1, ]$species_id, 6)
-
 })
 
 test_that("climate data flag works", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   vcr::use_cassette("npn_download_status_data_climate_flag_1", {
@@ -259,14 +285,12 @@ test_that("climate data flag works", {
   })
 
   expect_s3_class(some_data, "data.frame")
-  expect_null(some_data$tmin_winter)
-
+  expect_false("tmin_winter" %in% colnames(some_data))
 })
 
 
 test_that("higher taxonomic ordering works for status data", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   #Check the different taxonomic levels for
@@ -277,16 +301,16 @@ test_that("higher taxonomic ordering works for status data", {
     some_data <- npn_download_status_data(
       request_source = "Unit Test",
       years = 2013,
-      family_ids = c(322),
+      family_ids = c(109),
       additional_fields = c("Family_ID")
     )
   })
   expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
+  expect_gt(nrow(some_data), 100)
   expect_type(some_data$family_id, "integer")
-  expect_equal(some_data[1, ]$family_id, 322)
+  expect_equal(some_data[1, ]$family_id, 109)
 
-  less_data <- subset(some_data, species_id == 6)
+  less_data <- subset(some_data, species_id == 229)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
@@ -295,16 +319,16 @@ test_that("higher taxonomic ordering works for status data", {
     some_data <- npn_download_status_data(
       request_source = "Unit Test",
       years = 2013,
-      order_ids = c(95), #TODO pick a smaller order!
+      order_ids = c(94),
       additional_fields = c("Order_ID")
     )
   })
   expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
+  expect_gt(nrow(some_data), 500)
   expect_type(some_data$order_id, "integer")
-  expect_equal(some_data[1, ]$order_id, 95)
+  expect_equal(some_data[1, ]$order_id, 94)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 1211)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
@@ -313,17 +337,17 @@ test_that("higher taxonomic ordering works for status data", {
     some_data <- npn_download_status_data(
       request_source = "Unit Test",
       years = 2013,
-      class_ids = c(15), #TODO pick a smaller class or year with less data!
+      class_ids = c(11),
       additional_fields = c("Class_ID")
     )
   })
 
   expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
+  expect_gt(nrow(some_data), 100)
   expect_type(some_data$class_id, "integer")
-  expect_equal(some_data[1, ]$class_id, 15)
+  expect_equal(some_data[1, ]$class_id, 11)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 390)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 })
@@ -331,7 +355,6 @@ test_that("higher taxonomic ordering works for status data", {
 
 test_that("higher taxonomic ordering works for individual phenometrics", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   #Check the different taxonomic levels for
@@ -351,7 +374,7 @@ test_that("higher taxonomic ordering works for individual phenometrics", {
   expect_type(some_data$family_id, "integer")
   expect_equal(some_data[1, ]$family_id, 322)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
@@ -370,36 +393,33 @@ test_that("higher taxonomic ordering works for individual phenometrics", {
   expect_type(some_data$order_id, "integer")
   expect_equal(some_data[1, ]$order_id, 95)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
-
   # #class_ID
-  vcr::use_cassette("npn_download_individual_phenometrics_tax_3", {
-    some_data <- npn_download_individual_phenometrics(
-      request_source = "Unit Test",
-      years = 2013,
-      class_ids = c(15),
-      additional_fields = c("Class_ID")
-    )
-  })
-
-  expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
-  expect_type(some_data$class_id, "integer")
-  expect_equal(some_data[1, ]$class_id, 15)
-
-  less_data <- subset(some_data,species_id == 6)
-  expect_lt(nrow(less_data), nrow(some_data))
-  expect_gt(nrow(less_data), 0)
-
+  # vcr::use_cassette("npn_download_individual_phenometrics_tax_3", {
+  #   some_data <- npn_download_individual_phenometrics(
+  #     request_source = "Unit Test",
+  #     years = 2013,
+  #     class_ids = c(15),
+  #     additional_fields = c("Class_ID")
+  #   )
+  # })
+  #
+  # expect_s3_class(some_data, "data.frame")
+  # expect_gt(nrow(some_data), 1000)
+  # expect_type(some_data$class_id, "integer")
+  # expect_equal(some_data[1, ]$class_id, 15)
+  #
+  # less_data <- subset(some_data, species_id == 6)
+  # expect_lt(nrow(less_data), nrow(some_data))
+  # expect_gt(nrow(less_data), 0)
 })
 
 
 test_that("higher taxonomic ordering works for site phenometrics", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   #Check the different taxonomic levels for
@@ -419,7 +439,7 @@ test_that("higher taxonomic ordering works for site phenometrics", {
   expect_type(some_data$family_id, "integer")
   expect_equal(some_data[1, ]$family_id, 322)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
@@ -438,37 +458,33 @@ test_that("higher taxonomic ordering works for site phenometrics", {
   expect_type(some_data$order_id, "integer")
   expect_equal(some_data[1, ]$order_id, 95)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
-
   # #class_ID
-  vcr::use_cassette("npn_download_site_phenometrics_tax_3", {
-    some_data <- npn_download_site_phenometrics(
-      request_source = "Unit Test",
-      years = 2013,
-      class_ids = c(15),
-      additional_fields = c("Class_ID")
-    )
-  })
-
-  expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
-  expect_type(some_data$class_id, "integer")
-  expect_equal(some_data[1, ]$class_id, 15)
-
-  less_data <- subset(some_data,species_id == 6)
-  expect_lt(nrow(less_data), nrow(some_data))
-  expect_gt(nrow(less_data), 0)
-
-
+  # vcr::use_cassette("npn_download_site_phenometrics_tax_3", {
+  #   some_data <- npn_download_site_phenometrics(
+  #     request_source = "Unit Test",
+  #     years = 2013,
+  #     class_ids = c(15),
+  #     additional_fields = c("Class_ID")
+  #   )
+  # })
+  #
+  # expect_s3_class(some_data, "data.frame")
+  # expect_gt(nrow(some_data), 1000)
+  # expect_type(some_data$class_id, "integer")
+  # expect_equal(some_data[1, ]$class_id, 15)
+  #
+  # less_data <- subset(some_data, species_id == 6)
+  # expect_lt(nrow(less_data), nrow(some_data))
+  # expect_gt(nrow(less_data), 0)
 })
 
 
 test_that("higher taxonomic ordering works for magnitude phenometrics", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   #Check the different taxonomic levels for
@@ -489,7 +505,7 @@ test_that("higher taxonomic ordering works for magnitude phenometrics", {
   expect_type(some_data$family_id, "integer")
   expect_equal(some_data[1, ]$family_id, 322)
 
-  less_data <- subset(some_data,species_id == 6)
+  less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
@@ -508,36 +524,33 @@ test_that("higher taxonomic ordering works for magnitude phenometrics", {
   expect_type(some_data$order_id, "integer")
   expect_equal(some_data[1, ]$order_id, 95)
 
-  less_data <- subset(some_data,species_id == 6)
-  expect_lt(nrow(less_data), nrow(some_data))
-  expect_gt(nrow(less_data), 0)
-
-  # #class_ID
-  vcr::use_cassette("npn_download_magnitude_phenometrics_tax_3", {
-    some_data <- npn_download_magnitude_phenometrics(
-      request_source = "Unit Test",
-      years = 2013,
-      class_ids = c(15),
-      additional_fields = c("Class_ID")
-    )
-  })
-
-  expect_s3_class(some_data, "data.frame")
-  expect_gt(nrow(some_data), 1000)
-  expect_type(some_data$class_id, "integer")
-  expect_equal(some_data[1, ]$class_id, 15)
-
   less_data <- subset(some_data, species_id == 6)
   expect_lt(nrow(less_data), nrow(some_data))
   expect_gt(nrow(less_data), 0)
 
-
+  # #class_ID
+  # vcr::use_cassette("npn_download_magnitude_phenometrics_tax_3", {
+  #   some_data <- npn_download_magnitude_phenometrics(
+  #     request_source = "Unit Test",
+  #     years = 2013,
+  #     class_ids = c(15),
+  #     additional_fields = c("Class_ID")
+  #   )
+  # })
+  #
+  # expect_s3_class(some_data, "data.frame")
+  # expect_gt(nrow(some_data), 1000)
+  # expect_type(some_data$class_id, "integer")
+  # expect_equal(some_data[1, ]$class_id, 15)
+  #
+  # less_data <- subset(some_data, species_id == 6)
+  # expect_lt(nrow(less_data), nrow(some_data))
+  # expect_gt(nrow(less_data), 0)
 })
 
 
-test_that("higher level taxonomic agg and pheno agg works for site level",{
+test_that("higher level taxonomic agg and pheno agg works for site level", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   vcr::use_cassette("npn_download_site_phenometrics_pheno_agg_1", {
@@ -553,21 +566,21 @@ test_that("higher level taxonomic agg and pheno agg works for site level",{
   expect_gt(nrow(some_data), 10)
   expect_type(some_data$family_id, "integer")
   expect_equal(some_data[1, ]$family_id, 322)
-  expect_null(some_data$species_id)
-
+  expect_false("species_id" %in% colnames(some_data))
 
   vcr::use_cassette("npn_download_site_phenometrics_pheno_agg_2", {
     some_data <- npn_download_site_phenometrics(
       request_source = "Unit Test",
       years = 2013,
       family_ids = c(322),
-      pheno_class_aggregate = TRUE, pheno_class_ids = c(1, 3, 6)
+      pheno_class_aggregate = TRUE,
+      pheno_class_ids = c(1, 3, 6)
     )
   })
 
   expect_s3_class(some_data, "data.frame")
   expect_gt(nrow(some_data), 10)
-  expect_null(some_data$phenophase_id)
+  expect_false("phenophase_id" %in% colnames(some_data))
 
   vcr::use_cassette("npn_download_site_phenometrics_pheno_agg_3", {
     some_data <- npn_download_site_phenometrics(
@@ -584,14 +597,11 @@ test_that("higher level taxonomic agg and pheno agg works for site level",{
   expect_gt(nrow(some_data), 100)
   expect_type(some_data$pheno_class_name, "character")
   expect_type(some_data$order_id, "integer")
-  expect_null(some_data$phenophase_id)
-
-
+  expect_false("phenophase_id" %in% colnames(some_data))
 })
 
 test_that("higher level taxonomic agg works for magnitude", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
 
   vcr::use_cassette("npn_download_magnitude_phenometrics_pheno_agg_1", {
@@ -607,20 +617,21 @@ test_that("higher level taxonomic agg works for magnitude", {
   expect_gt(nrow(some_data), 10)
   expect_type(some_data$family_id, "integer")
   expect_equal(some_data[1, ]$family_id, 322)
-  expect_null(some_data$species_id)
+  expect_false("species_id" %in% colnames(some_data))
 
   vcr::use_cassette("npn_download_magnitude_phenometrics_pheno_agg_2", {
     some_data <- npn_download_magnitude_phenometrics(
       request_source = "Unit Test",
       years = 2013,
       family_ids = c(322),
-      pheno_class_aggregate = TRUE, pheno_class_ids = c(1, 3, 6)
+      pheno_class_aggregate = TRUE,
+      pheno_class_ids = c(1, 3, 6)
     )
   })
 
   expect_s3_class(some_data, "data.frame")
   expect_gt(nrow(some_data), 10)
-  expect_null(some_data$phenophase_id)
+  expect_false("phenophase_id" %in% colnames(some_data))
 
   vcr::use_cassette("npn_download_magnitude_phenometrics_pheno_agg_3", {
     some_data <- npn_download_magnitude_phenometrics(
@@ -637,26 +648,29 @@ test_that("higher level taxonomic agg works for magnitude", {
   expect_gt(nrow(some_data), 10)
   expect_type(some_data$pheno_class_name, "character")
   expect_type(some_data$order_id, "integer")
-  expect_null(some_data$phenophase_id)
-
+  expect_false("phenophase_id" %in% colnames(some_data))
 })
 
 test_that("six concordance works for status", {
   skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
   skip_if_not(check_service(), "Service is down")
+  skip_if(skip_long_tests)
 
-  vcr::use_cassette("npn_download_status_data_six_concord_1", {
-    some_data <- npn_download_status_data(
-      request_source = "Unit Test",
-      c(2016),
-      species_ids = c(6),
-      six_leaf_layer = TRUE,
-      six_bloom_layer = TRUE,
-      agdd_layer = 32,
-      additional_layers = data.frame(name = c("si-x:30yr_avg_4k_leaf"), param = c("365"))
+  #doesn't use vcr just because I suspect the fixture file will be very large
+  # vcr::use_cassette("npn_download_status_data_six_concord_1", {
+  some_data <- npn_download_status_data(
+    request_source = "Unit Test",
+    c(2016),
+    species_ids = c(6),
+    six_leaf_layer = TRUE,
+    six_bloom_layer = TRUE,
+    agdd_layer = 32,
+    additional_layers = data.frame(
+      name = c("si-x:30yr_avg_4k_leaf"),
+      param = c("365")
     )
-  })
+  )
+  # })
 
   expect_s3_class(some_data, "data.frame")
   expect_type(some_data$`SI-x_Bloom_Value`, "double")
@@ -677,61 +691,55 @@ test_that("six concordance works for status", {
   avg_leaf_data <- some_data$`SI-x_Leaf_Value`
 
   # Test sub-model functionality
-  vcr::use_cassette("npn_download_status_data_six_concord_2", {
-    some_data <- npn_download_status_data(
-      request_source = "Unit Test",
-      c(2016),
-      species_ids = c(6),
-      six_leaf_layer = TRUE,
-      six_sub_model = "lilac"
-    )
-  })
+  # vcr::use_cassette("npn_download_status_data_six_concord_2", {
+  some_data <- npn_download_status_data(
+    request_source = "Unit Test",
+    c(2016),
+    species_ids = c(6),
+    six_leaf_layer = TRUE,
+    six_sub_model = "lilac"
+  )
+  # })
 
   expect_gt(some_data[1, "SI-x_Leaf_Value"], -1)
   expect_lt(some_data[1, "SI-x_Leaf_Value"], 250)
   expect_false(identical(some_data$`SI-x_Leaf_Value`, avg_leaf_data))
 
-
   # This is testing that the implicit
   # reconciliation with different SI-x
   # layers is happening based on the date
   #
   # In this case get NCEP data
-  vcr::use_cassette("npn_download_status_data_six_concord_3", {
-    some_data <- npn_download_status_data(
-      request_source = "Unit Test",
-      c(2019),
-      species_ids = c(3),
-      six_leaf_layer = TRUE,
-      six_sub_model = "lilac"
-    )
-  })
+  # vcr::use_cassette("npn_download_status_data_six_concord_3", {
+  some_data <- npn_download_status_data(
+    request_source = "Unit Test",
+    c(2019),
+    species_ids = c(3),
+    six_leaf_layer = TRUE,
+    six_sub_model = "lilac"
+  )
+  # })
 
   expect_gt(some_data[1, "SI-x_Leaf_Value"], -1)
   expect_lt(some_data[1, "SI-x_Leaf_Value"], 250)
 
   # In this case get PRISM data
-  vcr::use_cassette("npn_download_status_data_six_concord_4", {
-    some_data <- npn_download_status_data(
-      request_source = "Unit Test",
-      c(2009),
-      species_ids = c(3),
-      six_leaf_layer = TRUE,
-      six_sub_model = "lilac"
-    )
-  })
+  # vcr::use_cassette("npn_download_status_data_six_concord_4", {
+  some_data <- npn_download_status_data(
+    request_source = "Unit Test",
+    c(2009),
+    species_ids = c(3),
+    six_leaf_layer = TRUE,
+    six_sub_model = "lilac"
+  )
+  # })
 
   expect_gt(some_data[1, "SI-x_Leaf_Value"], -1)
   expect_lt(some_data[1, "SI-x_Leaf_Value"], 250)
-
 })
 
 
 test_that("wkt filter works", {
-  skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
-  skip_if_not(check_service(), "Service is down")
-
   #wkt is for CO
   wkt_def <- "POLYGON ((-102.04224 36.993083,-109.045223 36.999084,-109.050076 41.000659,-102.051614 41.002377,-102.04224 36.993083))"
 
@@ -784,7 +792,6 @@ test_that("wkt filter works", {
   expect_equal(some_data[1, ]$state, "CO")
   expect_gt(rows_wo_filter, rows_w_filter)
 
-
   vcr::use_cassette("npn_download_site_phenometrics_wkt_1", {
     some_data <- npn_download_site_phenometrics(
       request_source = "Unit Test",
@@ -809,7 +816,6 @@ test_that("wkt filter works", {
   expect_equal(some_data[1, ]$state, "CO")
   expect_gt(rows_wo_filter, rows_w_filter)
 
-
   vcr::use_cassette("npn_download_magnitude_phenometrics_wkt_1", {
     some_data <- npn_download_magnitude_phenometrics(
       request_source = "Unit Test",
@@ -832,20 +838,16 @@ test_that("wkt filter works", {
   expect_s3_class(some_data, "data.frame")
   expect_type(some_data$species_id, "integer")
   expect_gt(rows_wo_filter, rows_w_filter)
-
 })
 
 
 test_that("frequency params work", {
-  skip_on_cran()
-  skip_if(skip_long_tests, "Skipping long tests")
-  skip_if_not(check_service(), "Service is down")
-
   vcr::use_cassette("npn_download_site_phenometrics_frequency_1", {
     some_data <- npn_download_site_phenometrics(
       request_source = "Unit Test",
       years = 2013,
-      family_ids = c(322), num_days_quality_filter = "30"
+      family_ids = c(322),
+      num_days_quality_filter = "30"
     )
   })
 
@@ -855,7 +857,8 @@ test_that("frequency params work", {
     some_data <- npn_download_site_phenometrics(
       request_source = "Unit Test",
       years = 2013,
-      family_ids = c(322), num_days_quality_filter = "15"
+      family_ids = c(322),
+      num_days_quality_filter = "15"
     )
   })
 
@@ -867,7 +870,8 @@ test_that("frequency params work", {
     some_data <- npn_download_magnitude_phenometrics(
       request_source = "Unit Test",
       years = 2013,
-      family_ids = c(322), period_frequency = "months"
+      family_ids = c(322),
+      period_frequency = "months"
     )
   })
 
@@ -877,11 +881,11 @@ test_that("frequency params work", {
     some_data <- npn_download_magnitude_phenometrics(
       request_source = "Unit Test",
       years = 2013,
-      family_ids = c(322), period_frequency = "14"
+      family_ids = c(322),
+      period_frequency = "14"
     )
   })
   rows_fortnight_freq <- nrow(some_data)
 
   expect_gt(rows_fortnight_freq, rows_month_freq)
-
 })
